@@ -2,13 +2,22 @@ import copy
 
 import pandas as pd
 
-from dtale.utils import (ChartBuildingError, classify_type, find_dtype,
-                         find_dtype_formatter, flatten_lists, get_dtypes,
-                         grid_columns, grid_formatter, json_int, make_list,
-                         run_query)
+from dtale.utils import (
+    ChartBuildingError,
+    classify_type,
+    find_dtype,
+    find_dtype_formatter,
+    flatten_lists,
+    get_dtypes,
+    grid_columns,
+    grid_formatter,
+    json_int,
+    make_list,
+    run_query,
+)
 
-YAXIS_CHARTS = ['line', 'bar', 'scatter']
-ZAXIS_CHARTS = ['heatmap', '3d_scatter', 'surface']
+YAXIS_CHARTS = ["line", "bar", "scatter"]
+ZAXIS_CHARTS = ["heatmap", "3d_scatter", "surface"]
 MAX_GROUPS = 30
 MAPBOX_TOKEN = None
 
@@ -42,11 +51,19 @@ def valid_chart(chart_type=None, x=None, y=None, z=None, **inputs):
     :return: `True` if executed from test, `False` otherwise
     :rtype: bool
     """
-    if chart_type == 'maps':
-        map_type = inputs.get('map_type')
-        if map_type == 'choropleth' and all(inputs.get(p) is not None for p in ['loc_mode', 'loc', 'map_val']):
+    if chart_type == "maps":
+        map_type = inputs.get("map_type")
+        if map_type == "choropleth" and all(
+            inputs.get(p) is not None for p in ["loc_mode", "loc", "map_val"]
+        ):
+            if inputs.get("loc_mode") == "geojson-id" and any(
+                inputs.get(p) is None for p in ["geojson", "featureidkey"]
+            ):
+                return False
             return True
-        elif map_type in ['scattergeo', 'mapbox'] and all(inputs.get(p) is not None for p in ['lat', 'lon']):
+        elif map_type in ["scattergeo", "mapbox"] and all(
+            inputs.get(p) is not None for p in ["lat", "lon"]
+        ):
             return True
         return False
 
@@ -56,7 +73,9 @@ def valid_chart(chart_type=None, x=None, y=None, z=None, **inputs):
     if chart_type in ZAXIS_CHARTS and z is None:
         return False
 
-    if inputs.get('agg') == 'rolling' and (inputs.get('window') is None or inputs.get('rolling_comp') is None):
+    if inputs.get("agg") == "rolling" and (
+        inputs.get("window") is None or inputs.get("rolling_comp") is None
+    ):
         return False
     return True
 
@@ -73,7 +92,7 @@ def build_formatters(df):
     """
     cols = grid_columns(df)
     data_f = grid_formatter(cols, nan_display=None)
-    overrides = {'F': lambda f, i, c: f.add_float(i, c, precision=2)}
+    overrides = {"F": lambda f, i, c: f.add_float(i, c, precision=2)}
     range_f = grid_formatter(cols, overrides=overrides, nan_display=None)
     return data_f, range_f
 
@@ -97,66 +116,74 @@ def date_freq_handler(df):
     orig_idx = df.index
 
     def _handler(col_def):
-        col_def_segs = col_def.split('|')
-        if len(col_def_segs) > 1 and classify_type(dtypes[col_def_segs[0]]) == 'D':
+        col_def_segs = col_def.split("|")
+        if len(col_def_segs) > 1 and classify_type(dtypes[col_def_segs[0]]) == "D":
             col, freq = col_def_segs
-            if freq == 'WD':
+            if freq == "WD":
                 code = "df.set_index('{col}').index.dayofweek.values"
                 freq_grp = df.set_index(col).index.dayofweek.values
-            elif freq == 'H2':
+            elif freq == "H2":
                 code = "df.set_index('{col}').index.hour.values"
                 freq_grp = df.set_index(col).index.hour.values
             else:
                 code = "df.set_index('{col}').index.to_period('{freq}').to_timestamp(how='end').values"
-                freq_grp = df.set_index(col).index.to_period(freq).to_timestamp(how='end').values
+                freq_grp = (
+                    df.set_index(col)
+                    .index.to_period(freq)
+                    .to_timestamp(how="end")
+                    .values
+                )
             code = "\tpd.Series(" + code + ", index=df.index, name='{col_def}'),"
             freq_grp = pd.Series(freq_grp, index=orig_idx, name=col_def)
             return freq_grp, code.format(col=col, freq=freq, col_def=col_def)
         else:
             return df[col_def], "\tdf['{col_def}'],".format(col_def=col_def)
+
     return _handler
 
 
 def group_filter_handler(col_def, group_val, group_classifier):
-    col_def_segs = col_def.split('|')
+    col_def_segs = col_def.split("|")
     if len(col_def_segs) > 1:
         col, freq = col_def_segs
-        if group_val == 'nan':
-            return '{col} != {col}'.format(col=col)
-        if freq == 'WD':
-            return '{}.dt.dayofweek == {}'.format(col, group_val)
-        elif freq == 'H2':
-            return '{}.dt.hour == {}'.format(col, group_val)
-        elif freq == 'H':
+        if group_val == "nan":
+            return "{col} != {col}".format(col=col)
+        if freq == "WD":
+            return "{}.dt.dayofweek == {}".format(col, group_val)
+        elif freq == "H2":
+            return "{}.dt.hour == {}".format(col, group_val)
+        elif freq == "H":
             ts_val = pd.Timestamp(group_val)
             return "{col}.dt.date == '{day}' and {col}.dt.hour == {hour}".format(
-                col=col, day=ts_val.strftime('%Y%m%d'), hour=ts_val.hour
+                col=col, day=ts_val.strftime("%Y%m%d"), hour=ts_val.hour
             )
-        elif freq == 'D':
+        elif freq == "D":
             ts_val = pd.Timestamp(group_val)
-            return "{col}.dt.date == '{day}'".format(col=col, day=ts_val.strftime('%Y%m%d'))
-        elif freq == 'W':
+            return "{col}.dt.date == '{day}'".format(
+                col=col, day=ts_val.strftime("%Y%m%d")
+            )
+        elif freq == "W":
             ts_val = pd.Timestamp(group_val)
             return "{col}.dt.year == {year} and {col}.dt.week == {week}".format(
                 col=col, year=ts_val.year, week=ts_val.week
             )
-        elif freq == 'M':
+        elif freq == "M":
             ts_val = pd.Timestamp(group_val)
             return "{col}.dt.year == {year} and {col}.dt.month == {month}".format(
                 col=col, year=ts_val.year, month=ts_val.month
             )
-        elif freq == 'Q':
+        elif freq == "Q":
             ts_val = pd.Timestamp(group_val)
             return "{col}.dt.year == {year} and {col}.dt.quarter == {quarter}".format(
                 col=col, year=ts_val.year, quarter=ts_val.quarter
             )
-        elif freq == 'Y':
+        elif freq == "Y":
             ts_val = pd.Timestamp(group_val)
             return "{col}.dt.year == {year}".format(col=col, year=ts_val.year)
-    if group_val == 'nan':
-        return '{col} != {col}'.format(col=col_def)
-    if group_classifier in ['I', 'F']:
-        return '{col} == {val}'.format(col=col_def, val=group_val)
+    if group_val == "nan":
+        return "{col} != {col}".format(col=col_def)
+    if group_classifier in ["I", "F"]:
+        return "{col} == {val}".format(col=col_def, val=group_val)
     return "{col} == '{val}'".format(col=col_def, val=group_val)
 
 
@@ -170,11 +197,11 @@ def build_group_inputs_filter(df, group_inputs):
 
     def _full_filter():
         for group_val in group_inputs:
-            group_filter = ' and '.join(list(_group_filter(group_val)))
+            group_filter = " and ".join(list(_group_filter(group_val)))
             yield group_filter
 
     filters = list(_full_filter())
-    return '({})'.format(') or ('.join(filters))
+    return "({})".format(") or (".join(filters))
 
 
 def retrieve_chart_data(df, *args, **kwargs):
@@ -201,10 +228,10 @@ def retrieve_chart_data(df, *args, **kwargs):
                 all_code.append(code)
     all_data = pd.concat(all_data, axis=1)
     all_code = ["chart_data = pd.concat(["] + all_code + ["], axis=1)"]
-    if len(make_list(kwargs.get('group_val'))):
-        filters = build_group_inputs_filter(all_data, kwargs['group_val'])
+    if len(make_list(kwargs.get("group_val"))):
+        filters = build_group_inputs_filter(all_data, kwargs["group_val"])
         all_data = run_query(all_data, filters)
-        all_code.append('chart_data = chart_data.query({})'.format(filters))
+        all_code.append("chart_data = chart_data.query({})".format(filters))
     return all_data, all_code
 
 
@@ -223,10 +250,21 @@ def check_all_nan(df, cols=None):
             raise Exception('All data for column "{}" is NaN!'.format(col))
 
 
-LIMIT_MSG = 'Dataset exceeds {} records, cannot render. Please apply filter...'
+DUPES_MSG = (
+    "{} contains duplicates, please specify group or additional filtering or select 'No Aggregation' from"
+    " Aggregation drop-down."
+)
+LIMIT_MSG = "Dataset exceeds {} records, cannot render. Please apply filter..."
 
 
-def check_exceptions(df, allow_duplicates, unlimited_data=False, data_limit=15000, limit_msg=LIMIT_MSG):
+def check_exceptions(
+    df,
+    allow_duplicates,
+    unlimited_data=False,
+    data_limit=15000,
+    limit_msg=LIMIT_MSG,
+    dupes_msg=DUPES_MSG,
+):
     """
     Checker function to test the output of any chart aggregations to see if it is one of the following:
         - too large to be rendered by web client
@@ -244,10 +282,7 @@ def check_exceptions(df, allow_duplicates, unlimited_data=False, data_limit=1500
     :raises Exception: if any failure condition is met
     """
     if not allow_duplicates and any(df.duplicated()):
-        raise ChartBuildingError((
-            "{} contains duplicates, please specify group or additional filtering or select 'No Aggregation' from"
-            ' Aggregation drop-down.'
-        ).format(', '.join(df.columns)))
+        raise ChartBuildingError(dupes_msg.format(", ".join(df.columns)))
     if not unlimited_data and len(df) > data_limit:
         raise ChartBuildingError(limit_msg.format(data_limit))
 
@@ -273,25 +308,33 @@ def build_agg_data(df, x, y, inputs, agg, z=None, group_col=None, animate_by=Non
     :return: dataframe of aggregated data
     :rtype: :class:`pandas:pandas.DataFrame`
     """
-    if agg == 'raw':
+    if agg == "raw":
         return df, []
     z_exists = len(make_list(z))
-    if agg == 'corr':
+    if agg == "corr":
         if not z_exists:
-            raise NotImplementedError('Correlation aggregation is only available for 3-dimensional charts!')
-    if agg == 'rolling':
+            raise NotImplementedError(
+                "Correlation aggregation is only available for 3-dimensional charts!"
+            )
+    if agg == "rolling":
         if z_exists:
-            raise NotImplementedError('Rolling computations have not been implemented for 3-dimensional charts!')
-        window, comp = map(inputs.get, ['rolling_win', 'rolling_comp'])
+            raise NotImplementedError(
+                "Rolling computations have not been implemented for 3-dimensional charts!"
+            )
+        window, comp = map(inputs.get, ["rolling_win", "rolling_comp"])
         agg_df = df.set_index(x).rolling(window=window)
         agg_df = pd.DataFrame({c: getattr(agg_df[c], comp)() for c in y})
         agg_df = agg_df.reset_index()
         code = [
-            "chart_data = chart_data.set_index('{x}').rolling(window={window})".format(x=x, window=window),
-            "chart_data = pd.DataFrame({'" + ', '.join(
+            "chart_data = chart_data.set_index('{x}').rolling(window={window})".format(
+                x=x, window=window
+            ),
+            "chart_data = pd.DataFrame({'"
+            + ", ".join(
                 ["'{c}': chart_data['{c}'].{comp}()".format(c=c, comp=comp) for c in y]
-            ) + '})',
-            "chart_data = chart_data.reset_index()"
+            )
+            + "})",
+            "chart_data = chart_data.reset_index()",
         ]
         return agg_df, code
 
@@ -302,8 +345,8 @@ def build_agg_data(df, x, y, inputs, agg, z=None, group_col=None, animate_by=Non
         agg_cols = make_list(z)
 
     groups = df.groupby(idx_cols)
-    if agg in ['pctsum', 'pctct']:
-        func = 'sum' if agg == 'pctsum' else 'size'
+    if agg in ["pctsum", "pctct"]:
+        func = "sum" if agg == "pctsum" else "size"
         subidx_cols = [c for c in idx_cols if c not in make_list(group_col)]
         groups = getattr(groups[agg_cols], func)()
         groups = groups / getattr(df.groupby(subidx_cols)[agg_cols], func)() * 100
@@ -316,8 +359,12 @@ def build_agg_data(df, x, y, inputs, agg, z=None, group_col=None, animate_by=Non
             "chart_data = chart_data / chart_data.groupby(['{subidx_cols}']).{agg}()\n"
             "chart_data = chart_data.reset_index()"
         )
-        code = code.format(cols="', '".join(idx_cols), subidx_cols="', '".join(subidx_cols),
-                           agg_cols="', '".join(agg_cols), agg=func)
+        code = code.format(
+            cols="', '".join(idx_cols),
+            subidx_cols="', '".join(subidx_cols),
+            agg_cols="', '".join(agg_cols),
+            agg=func,
+        )
         code = [code]
     else:
         groups = getattr(groups[agg_cols], agg)()
@@ -327,18 +374,31 @@ def build_agg_data(df, x, y, inputs, agg, z=None, group_col=None, animate_by=Non
             )
         ]
     if animate_by is not None:
-        full_idx = pd.MultiIndex.from_product([df[c].unique() for c in idx_cols], names=idx_cols)
+        full_idx = pd.MultiIndex.from_product(
+            [df[c].unique() for c in idx_cols], names=idx_cols
+        )
         groups = groups.reindex(full_idx).fillna(0)
         code += [
             "idx_cols = ['{cols}']".format(cols="', '".join(idx_cols)),
-            'full_idx = pd.MultiIndex.from_product([df[c].unique() for c in idx_cols], names=idx_cols)'
-            'chart_data = chart_data.reindex(full_idx).fillna(0)'
+            "full_idx = pd.MultiIndex.from_product([df[c].unique() for c in idx_cols], names=idx_cols)"
+            "chart_data = chart_data.reindex(full_idx).fillna(0)",
         ]
     return groups.reset_index(), code
 
 
-def build_base_chart(raw_data, x, y, group_col=None, group_val=None, agg=None, allow_duplicates=False, return_raw=False,
-                     unlimited_data=False, animate_by=None, **kwargs):
+def build_base_chart(
+    raw_data,
+    x,
+    y,
+    group_col=None,
+    group_val=None,
+    agg=None,
+    allow_duplicates=False,
+    return_raw=False,
+    unlimited_data=False,
+    animate_by=None,
+    **kwargs
+):
     """
     Helper function to return data for 'chart-data' & 'correlations-ts' endpoints.  Will return a dictionary of
     dictionaries (one for each series) which contain the data for the x & y axes of the chart as well as the minimum &
@@ -361,41 +421,64 @@ def build_base_chart(raw_data, x, y, group_col=None, group_val=None, agg=None, a
     :type allow_duplicates: bool, optional
     :return: dict
     """
-    group_fmt_overrides = {'I': lambda v, as_string: json_int(v, as_string=as_string, fmt='{}')}
-    data, code = retrieve_chart_data(raw_data, x, y, kwargs.get('z'), group_col, animate_by, group_val=group_val)
-    x_col = str('x')
+    group_fmt_overrides = {
+        "I": lambda v, as_string: json_int(v, as_string=as_string, fmt="{}")
+    }
+    data, code = retrieve_chart_data(
+        raw_data, x, y, kwargs.get("z"), group_col, animate_by, group_val=group_val
+    )
+    x_col = str("x")
     y_cols = make_list(y)
-    z_col = kwargs.get('z')
+    z_col = kwargs.get("z")
     z_cols = make_list(z_col)
-    sort_cols = (y_cols if len(z_cols) else [])
+    sort_cols = y_cols if len(z_cols) else []
     if group_col is not None and len(group_col):
         main_group = group_col
         if animate_by is not None:
             main_group = [animate_by] + main_group
         sort_cols = main_group + [x] + sort_cols
         data = data.sort_values(sort_cols)
-        code.append("chart_data = chart_data.sort_values(['{cols}'])".format(cols="', '".join(sort_cols)))
+        code.append(
+            "chart_data = chart_data.sort_values(['{cols}'])".format(
+                cols="', '".join(sort_cols)
+            )
+        )
         check_all_nan(data)
         data = data.rename(columns={x: x_col})
-        code.append("chart_data = chart_data.rename(columns={'" + x + "': '" + x_col + "'})")
+        code.append(
+            "chart_data = chart_data.rename(columns={'" + x + "': '" + x_col + "'})"
+        )
         if agg is not None:
-            data, agg_code = build_agg_data(data, x_col, y_cols, kwargs, agg, z=z_col, group_col=group_col,
-                                            animate_by=animate_by)
+            data, agg_code = build_agg_data(
+                data,
+                x_col,
+                y_cols,
+                kwargs,
+                agg,
+                z=z_col,
+                group_col=group_col,
+                animate_by=animate_by,
+            )
             code += agg_code
         MAX_GROUPS = 30
         group_vals = data[group_col].drop_duplicates()
         if len(group_vals) > MAX_GROUPS:
             dtypes = get_dtypes(group_vals)
-            group_fmts = {c: find_dtype_formatter(dtypes[c], overrides=group_fmt_overrides) for c in group_col}
+            group_fmts = {
+                c: find_dtype_formatter(dtypes[c], overrides=group_fmt_overrides)
+                for c in group_col
+            }
 
             group_f, _ = build_formatters(group_vals)
             group_vals = group_f.format_lists(group_vals)
             group_vals = pd.DataFrame(group_vals, columns=group_col)
             msg = (
-                'Group ({}) contains more than {} unique values, more groups than that will make the chart unreadable. '
+                "Group ({}) contains more than {} unique values, more groups than that will make the chart unreadable. "
                 'You can choose specific groups to display from then "Group(s)" dropdown above. The available group(s) '
-                'are listed below:\n\n{}'
-            ).format(', '.join(group_col), MAX_GROUPS, group_vals.to_string(index=False))
+                "are listed below:\n\n{}"
+            ).format(
+                ", ".join(group_col), MAX_GROUPS, group_vals.to_string(index=False)
+            )
             raise ChartBuildingError(msg, group_vals.to_string(index=False))
 
         data = data.dropna()
@@ -405,12 +488,23 @@ def build_base_chart(raw_data, x, y, group_col=None, group_val=None, agg=None, a
         data_f, range_f = build_formatters(data)
         ret_data = dict(
             data={},
-            min={col: fmt(data[col].min(), None) for _, col, fmt in range_f.fmts if col in [x_col] + y_cols + z_cols},
-            max={col: fmt(data[col].max(), None) for _, col, fmt in range_f.fmts if col in [x_col] + y_cols + z_cols},
+            min={
+                col: fmt(data[col].min(), None)
+                for _, col, fmt in range_f.fmts
+                if col in [x_col] + y_cols + z_cols
+            },
+            max={
+                col: fmt(data[col].max(), None)
+                for _, col, fmt in range_f.fmts
+                if col in [x_col] + y_cols + z_cols
+            },
         )
 
         dtypes = get_dtypes(data)
-        group_fmts = {c: find_dtype_formatter(dtypes[c], overrides=group_fmt_overrides) for c in group_col}
+        group_fmts = {
+            c: find_dtype_formatter(dtypes[c], overrides=group_fmt_overrides)
+            for c in group_col
+        }
 
         def _load_groups(df):
             for group_val, grp in df.groupby(group_col):
@@ -418,38 +512,53 @@ def build_base_chart(raw_data, x, y, group_col=None, group_val=None, agg=None, a
                 def _group_filter():
                     for gv, gc in zip(make_list(group_val), group_col):
                         classifier = classify_type(dtypes[gc])
-                        yield group_filter_handler(gc, group_fmts[gc](gv, as_string=True), classifier)
+                        yield group_filter_handler(
+                            gc, group_fmts[gc](gv, as_string=True), classifier
+                        )
 
-                group_filter = ' and '.join(list(_group_filter()))
+                group_filter = " and ".join(list(_group_filter()))
                 yield group_filter, data_f.format_lists(grp)
 
         if animate_by is not None:
-            frame_fmt = find_dtype_formatter(dtypes[animate_by], overrides=group_fmt_overrides)
-            ret_data['frames'] = []
+            frame_fmt = find_dtype_formatter(
+                dtypes[animate_by], overrides=group_fmt_overrides
+            )
+            ret_data["frames"] = []
             for frame_key, frame in data.sort_values(animate_by).groupby(animate_by):
-                ret_data['frames'].append(
-                    dict(data=dict(_load_groups(frame)), name=frame_fmt(frame_key, as_string=True))
+                ret_data["frames"].append(
+                    dict(
+                        data=dict(_load_groups(frame)),
+                        name=frame_fmt(frame_key, as_string=True),
+                    )
                 )
-            ret_data['data'] = copy.deepcopy(ret_data['frames'][-1]['data'])
+            ret_data["data"] = copy.deepcopy(ret_data["frames"][-1]["data"])
         else:
-            ret_data['data'] = dict(_load_groups(data))
+            ret_data["data"] = dict(_load_groups(data))
         return ret_data, code
     main_group = [x]
     if animate_by is not None:
         main_group = [animate_by] + main_group
     sort_cols = main_group + sort_cols
     data = data.sort_values(sort_cols)
-    code.append("chart_data = chart_data.sort_values(['{cols}'])".format(cols="', '".join(sort_cols)))
+    code.append(
+        "chart_data = chart_data.sort_values(['{cols}'])".format(
+            cols="', '".join(sort_cols)
+        )
+    )
     check_all_nan(data)
     y_cols = [str(y_col) for y_col in y_cols]
     data = data[main_group + y_cols + z_cols]
 
     data = data.rename(columns={x: x_col})
     main_group = [x_col if c == x else c for c in main_group]
-    code.append("chart_data = chart_data.rename(columns={'" + x + "': '" + x_col + "'})")
+    code.append(
+        "chart_data = chart_data.rename(columns={'" + x + "': '" + x_col + "'})"
+    )
 
     if agg is not None:
-        data, agg_code = build_agg_data(data, x_col, y_cols, kwargs, agg, z=z_col, animate_by=animate_by)
+        data, agg_code = build_agg_data(
+            data, x_col, y_cols, kwargs, agg, z=z_col, animate_by=animate_by
+        )
         code += agg_code
     data = data.dropna()
     if return_raw:
@@ -459,30 +568,46 @@ def build_base_chart(raw_data, x, y, group_col=None, group_val=None, agg=None, a
     dupe_cols = main_group + (y_cols if len(z_cols) else [])
     check_exceptions(
         data[dupe_cols].rename(columns={x_col: x}),
-        allow_duplicates or agg == 'raw',
+        allow_duplicates or agg == "raw",
         unlimited_data=unlimited_data,
-        data_limit=40000 if len(z_cols) or animate_by is not None else 15000
+        data_limit=40000 if len(z_cols) or animate_by is not None else 15000,
     )
     data_f, range_f = build_formatters(data)
 
     ret_data = dict(
-        min={col: fmt(data[col].min(), None) for _, col, fmt in range_f.fmts if col in [x_col] + y_cols + z_cols},
-        max={col: fmt(data[col].max(), None) for _, col, fmt in range_f.fmts if col in [x_col] + y_cols + z_cols}
+        min={
+            col: fmt(data[col].min(), None)
+            for _, col, fmt in range_f.fmts
+            if col in [x_col] + y_cols + z_cols
+        },
+        max={
+            col: fmt(data[col].max(), None)
+            for _, col, fmt in range_f.fmts
+            if col in [x_col] + y_cols + z_cols
+        },
     )
     if animate_by is not None:
-        frame_fmt = find_dtype_formatter(find_dtype(data[animate_by]), overrides=group_fmt_overrides)
-        ret_data['frames'] = []
+        frame_fmt = find_dtype_formatter(
+            find_dtype(data[animate_by]), overrides=group_fmt_overrides
+        )
+        ret_data["frames"] = []
         for frame_key, frame in data.sort_values(animate_by).groupby(animate_by):
-            ret_data['frames'].append(
-                dict(data={str('all'): data_f.format_lists(frame)}, name=frame_fmt(frame_key, as_string=True))
+            ret_data["frames"].append(
+                dict(
+                    data={str("all"): data_f.format_lists(frame)},
+                    name=frame_fmt(frame_key, as_string=True),
+                )
             )
-        ret_data['data'] = copy.deepcopy(ret_data['frames'][-1]['data'])
+        ret_data["data"] = copy.deepcopy(ret_data["frames"][-1]["data"])
     else:
-        ret_data['data'] = {str('all'): data_f.format_lists(data)}
+        ret_data["data"] = {str("all"): data_f.format_lists(data)}
     return ret_data, code
 
 
-WEEKDAY_MAP = {idx: day for idx, day in enumerate(['Mon', 'Tues', 'Wed', 'Thur', 'Fri', 'Sat', 'Sun'])}
+WEEKDAY_MAP = {
+    idx: day
+    for idx, day in enumerate(["Mon", "Tues", "Wed", "Thur", "Fri", "Sat", "Sun"])
+}
 
 
 def weekday_tick_handler(col_data, col):
@@ -498,7 +623,7 @@ def weekday_tick_handler(col_data, col):
     :return: formatted column data
     :rtype: list
     """
-    if col.endswith('|WD'):
+    if col.endswith("|WD"):
         return [WEEKDAY_MAP[d] for d in col_data]
     return col_data
 
